---
title: Build Notes
parent: Haptic Box 
date: 2022-07-05
edited: 2022-08-02
show-dates: true
todo:
  - proper TOC
  - spacing around paragraphs & consecutive images could be looked at
  - spacing around <li> could be looked at
  - consistent capitalization on headers
---

::: contents

### Contents

- [Overview](#overview)
- [Gathering components](#gathering-components)
- [Making the preamp](#preamp)
- [Making the box](#box)
- [Final assembly](#final-assembly)
- [Next steps](#next-steps)
- [_Notes_](#fn1)

:::

During the winter of 2021-2022 I built a [haptic box](/works/haptic-box), drawing on some insights, skill, and material garnered in the making of the [maple box](/maple-box.html) and [Pathside Box](/works/pathside-box.html). On this page you'll find reflections on and documentation of my build process. This build, like most of mine, was experimental, but I hope that it offers enough insight for future builders. If you have any comments or questions, I would love [to hear from you](/about.html).

This page discusses the physical assembly. Notes about assembling the code are on [this page](/works/haptic-box/code.html). The resources associated with the build can be found on [GitLab](https://gitlab.com/daveriedstra/haptic-box/-/tree/main/build).

# Overview: What is this thing? ^[↑](#top){.toplink}^ {#overview}

![Haptic Box and a plant](/img/haptic-box-with-plant-800.jpg "Haptic Box and a plant"){
    srcset="/img/haptic-box-with-plant-400.jpg 0.5x,
    /img/haptic-box-with-plant-1600.jpg 2x,
    /img/haptic-box-with-plant-2000.jpg 2.5x"
}

A haptic box is a wooden box built for sonic feedback in the tactile register. I designed this one to run a purpose-built feedback composition while being flexible enough for other uses (characterful output, input, filter, feedback instrument, etc) and also repairable and extensible. Hardware features include:

- Stereo inputs using piezo pickups
- Stereo outputs using contact exciter transducers
- Onboard preamp and amplifier for inputs and outputs
- Onboard Raspberry Pi and low-latency capable DAC
- Onboard power for all components
- Input & output jacks (stereo 1/4" phono)
- Switches to select internal vs external source / destination for the amplifiers
- Switches to power the amps and Raspberry Pi
- A button to safely shut down the Raspberry Pi

![Haptic Box cross section](/img/haptic-box-open-20220204-800.jpg "Haptic Box cross section"){
    srcset="/img/haptic-box-open-20220204-400.jpg 0.5x,
    /img/haptic-box-open-20220204-1600.jpg 2x,
    /img/haptic-box-open-20220204-2000.jpg 2.5x"
}

# Gathering Components ^[↑](#top){.toplink}^

The box uses the following components. Some are fairly common, many can be substituted.

## Electronics ^[↑](#top){.toplink}^

- Raspberry Pi
    - I used a model 3B+, other models should work fine.
    - A [Bela](https://bela.io/) (or the mini version) could be an interesting alternative that might also fill the role of the amplifier and preamp.
- [AudioInjector Stereo sound card](https://www.audioinjector.net/rpi-hat)
    - Documentation for AudioInjector is primarily in the [mailing list](https://lists.audioinjector.net/pipermail/people/).
    - Alternatives include other products from [AudioInjector](https://www.audioinjector.net/) as well as [Blokas](https://blokas.io/), [elk.audio](https://elk.audio/), and [HiFi Berry](https://www.hifiberry.com/) (as long as it has low latency).
- USB powerbank
    - I used an Anker PowerCore 5000, but something less cylindrical might be easier to mount.
    - An alternative must meet the power requirements of the Raspberry Pi [here](https://www.raspberrypi.com/documentation/computers/raspberry-pi.html#power-supply). Specifically, the supply must provide 5.1V for any model of Pi, though the current draw depends on what the Pi is doing. Pi models 3A / B / B+ can draw up to 2.5A, but my 3B runs well enough with the Anker bank mentioned above, which only provides 2.0A. The power supply also needs to be stable enough to power the Pi while running low-latency audio.
- 2 transducers
    - I used a moderately large size and power in order to provide lower frequencies ([Dayton Audio DAEX25CT-4](https://www.daytonaudio.com/product/1175/daex25ct-4-coin-type-25mm-exciter-10w-4-ohm))
- 2 piezoelectric elements
    - Again a decent size to pick up lower frequencies (41mm), other sizes will work but have different frequency responses
    - [https://www.mouser.ca/ProductDetail/497-P27040-2](https://www.mouser.ca/ProductDetail/497-P27040-2)
- An amplifier for the transducers
    - I used the [Adafruit 20W amp](https://www.adafruit.com/product/1752)
- A preamp or buffer for the piezos
    - I built a modified version of Richard Mudhar's [low-noise hi-Z amplifier](https://www.richardmudhar.com/blog/piezo-contact-microphone-hi-z-amplifier-low-noise-version/). Designs, alternatives, and building process are discussed [below](#preamp).
    - Off-the-shelf options might exist, but I was unable to find one small and portable enough to mount inside the box.
- A 9V battery to power the amp & preamp
    - This is used because running the amps off of the same battery that powers the Pi introduced audible noise.
- Connection hardware
    - 2x 1/4" TRS phono jacks
    - Switches
        - 2x SPST (simple on-off switches for power)
        - 2x 3PDT (3-channel switches for audio routing)
    - Momentary button for soft-shutdown
    - 9V battery terminal
    - A stereo RCA to RCA cable
    - A USB A to USB micro cable
    - Wire & solder
- Mounting hardware
    - Standoffs to mount the Raspberry Pi and amplifiers (11mm, M2.5)
        - Can be bought from most places that sell Raspberry Pis or similar hobbyist electronics
    - [Command picture-hanging strips](https://command.3m.co.uk/3M/en_GB/command-gb/products/?N=5002385+8711749+8723963&rt=r3) to mount both batteries
        - Velcro brand strips may be less expensive, but I found they were weaker and shed a lot

## Material ^[↑](#top){.toplink}^

::: alignright
![Mystery softwood offcut for the panels](/img/resized/box-panel-offcut-400.jpg "Mystery softwood offcut for the panels")
:::

I made this box from wood I had ready access to. The spine is hard maple I had previously bought from a nearby syrup making family (bought as a rough-cut 2in × 6in × 8ft board), and the panels are an unknown softwood (probably cedar) from an offcut of a bannister (roughly 2in × 9in × 6ft). If I hadn't found the offcut, I would have sourced some other softwood, as the maple used in maple box was very stiff. Additionally, this maple was very difficult for my fledgeling hand-tool woodworking skills and in the future I'll opt for something somewhat softer (though the hardness does mean the box is quite sturdy).

The [cut list](#cut-list) is below.

# The Preamp ^[↑](#top){.toplink}^ {#preamp}

Piezoelectronic transducers require a preamp or a buffer primarily in order to match their impedance with line-level inputs, as well as to provide extra gain.[^preamp-impedance] There are a number of designs available online, I chose to build a two-channel version of Richard Mudhar's [low-noise hi-Z piezo preamp](https://www.richardmudhar.com/blog/piezo-contact-microphone-hi-z-amplifier-low-noise-version/).[^preamp-designs] I used a stereo version of Scott Helmke's [mint-box piezo buffer](http://www.scotthelmke.com/Mint-box-buffer.html) in the [Maple Box](/maple-box.html), but I chose the Mudhar preamp for this project because it offers more gain and better noise performance. The Mudhar preamp is very clean-sounding but its components are a bit more expensive and it sounds pretty ugly when it clips. The Helmke buffer is quieter, more coloured, and clips more pleasantly.

- [schematic]()
- [stripboard layout]()
- [breadboard layout]()
- [BOM]()

::: aligngrid
![The preamp circuit ([annotated version](/img/mudhar-stereo-stripboard-diagram.svg))](/img/preamp-finished-800.jpg "The preamp circuit"){
    srcset="/img/preamp-finished-400.jpg 0.5x,
    /img/preamp-finished-1600.jpg 2x,
    /img/preamp-finished-2000.jpg 2.5x"
}

![The underside of the preamp during soldering](/img/preamp-underside-800.jpg "The underside of the preamp during soldering"){
    srcset="/img/preamp-underside-400.jpg 0.5x,
    /img/preamp-underside-1600.jpg 2x,
    /img/preamp-underside-2000.jpg 2.5x"
}
:::

The schematic on Mudhar's website is for a single piezo pickup, so I had to modify it to work with two. The resulting circuit is basically the same as running two of the preamp from the same power supply (though I omitted the duplicate filter capacitor). I'm waiting on a reply from Mudhar about whether I'm allowed to publish the schematic for this simple dual version here.

I'm happy with the sound and performance of the preamp, though there were a few things I would have done differently when building. Mainly, I would have laid it out on the stripboard, labelled the terminals and marked the positions of the components, then removed everything before cutting the board to size and drilling the mounting hole. I didn't cut the board beforehand and was pretty lucky that it didn't break! Otherwise, the build was pretty straightforward.

<!-- ![The preamp laid out to solder](/img/preamp-laid-out-800.jpg "The preamp laid out to solder"){ -->
<!--     srcset="/img/preamp-laid-out-400.jpg 0.5x, -->
<!--     /img/preamp-laid-out-1600.jpg 2x, -->
<!--     /img/preamp-laid-out-2000.jpg 2.5x" -->
<!-- } -->

[^preamp-impedance]: Richard Mudhar [writes about impedance matching](https://www.richardmudhar.com/using-piezo-contact-mics-right/) and there is a wealth of knowledge on various musician forums like [llllllll](https://llllllll.co/t/contact-mics/5312) and [talkbass](https://www.talkbass.com/threads/so-i-got-a-piezo-buzzer-from-radio-shack.131882/). Murray Royston Ward [shares resources](https://mroystonward.gitlab.io/) on a more creative approach to preamp building. If you want to dig into the theory to design one yourself, this [piezo sensors technical manual](https://www.contactmicrophones.com/techman.pdf) might be a good place to start. (Links last retrieved 2022-07-06).

[^preamp-designs]: Richard Mudhar has a [lower cost design](https://www.richardmudhar.com/piezo-contact-microphone-hi-z-amplifier-using-a-fet/) using a FET (which I think means it should clip more pleasantly). Scott Helmke's design is [here](http://www.scotthelmke.com/Mint-box-buffer.html). The [Barcus Berry Preamp](https://tagboardeffects.blogspot.com/2017/05/barcus-berry-3000a-buffer-preamp-eq.html) is mentioned frequently. Zach Poff gives some detail and schematics on a design by Alex Rice [here](https://www.zachpoff.com/resources/alex-rice-piezo-preamplifier/). The Centre for Haptic Audio Interaction Research has a [very simple JFET-based design](https://www.chair.audio/diy-piezo-preamp/) which I haven't yet tried. Instructables user backbeats has also contributed a [JFET-based design](https://www.instructables.com/Guitar-Contact-Microphone-Preamp/) intended for use as an acoustic guitar pickup. (Links last retrieved 2022-07-06).

# The Box ^[↑](#top){.toplink}^ {#box}

The box is a book shape open on the bottom edge with external dimensions 51cm long × 22.6cm high × 12.5cm wide. The "spine" extends beyond the bottom panels to provide feet. I used box joints on the spine which is reflected in the cut list dimensions.

![[Diagrams of the box and a cut list](/img/box-diagrams.svg)](/img/box-diagrams.svg "Diagrams of the box and a cut list of its parts")

The box ended up a little bigger than expected in order to meet my design criteria. I wanted symmetrical broad surfaces for the vibrations, large enough to accommodate an entire hand. The box needed to house all the electronics, which took up quite a bit of space (especially accounting for the room that connections take up). I also wanted to keep the internals accessible for maintenance, upgrades, and maybe even temporarily removing the hardware for use in other projects. As big as it is, access is still constrained, so potential future designs will need to address that issue.

## Cut List ^[↑](#top){.toplink}^

- Panels: 2 at 51cm × 21cm × 0.6cm
- Spine sides: 2 at 22.6cm × 11.3cm × 0.8cm
- Spine top: 1 at 51cm × 11.3cm × 0.8cm
- Various offcuts used for internal routing conduits

## The Build ^[↑](#top){.toplink}^

::: alignright
![Resawing the panel](/img/resized/box-resawing-panel-400.jpg "Resawing the panel")
:::

Since my workshop is quite small, I was limited to using hand tools for this project (and all of my others). I won't launch into some paean extolling the virtues of working without electricity (which wouldn't mean much since I don't have much experience working with power tools anyway), but I do think it's worth reflecting on. I absolutely did suffer due to this: a single resawing operation took most of an afternoon, after which my back and wrists ached and I coughed from inhaling sawdust – and I did three of them. But spending that much time in close contact with the material surely results in increased familiarity with and attachment to it.

<!-- **TODO: images; review images to make sure these steps are right; add reflections?** -->

Dimensioning the boards with hand tools meant planing the rough-sawn boards to square, cutting to width, resawing to the correct thickness, planing the resawn face, and then cutting to length. This was quite labour intensive, particularly as the maple I used was difficult to work with (it was very hard, twisted and cupped, and had a few knots).

<!-- TODO: make this markup and layout less ugly! -->

::: {.alignleft}
![The resawn panels](/img/resized/box-resawn-panels-800.jpg "The resawn panels")
:::

<!--
<div>
<div style="float: left;">
![rough cut maple for the spine](/img/resized/box-spine-rough-sawn-400.jpg "rough cut maple for the spine")
</div>
<div style="float: left;">
![rough cut mystery softwood offcut for the panels](/img/resized/box-panel-offcut-400.jpg "rough cut mystery softwood offcut for the panels")
</div>
<div style="float: left;">
![resawing the panel](/img/resized/box-resawing-panel-400.jpg "resawing the panel")
</div>
<div style="float: left;">
![the resawn panels](/img/resized/box-resawn-panels-400.jpg "the resawn panels")
</div>
</div>
-->

<!-- <div style="clear: both;"> -->
I used box joints to join the three pieces of the spine. Box joints are sturdy enough to give structure and not as complicated as dovetails. Like much of my other woodworking skills, I had learned these from watching instructional videos like [Paul Sellars's](https://youtu.be/channel/UCc3EpWncNq5QL0QhwUNQb7w). I had cut box joints for the maple box and was eager to try again. The result was about the same: fine from a distance. The dry fit shows some overhang in the joint fingers which I cleaned up afterward with a plane.

<!-- Next, cut the joints for the spine. If you haven't done this before, give it a shot! There are lots of resources online for learning joinery and hand tool woodworking, I recommend [Paul Sellars's YouTube videos](https://youtu.be/channel/UCc3EpWncNq5QL0QhwUNQb7w). Sellars seems to prefer dovetail joints, but I used box joints since they looked a little simpler. If you're going to skip cutting an interlocking joint and just use glue or screws, be sure to adjust the cut of your wood accordingly, as you won't need the overlap. Also be aware that your joint might not be as sturdy, though once the panels are glued on I don't think this will be a huge concern. -->
<!-- </div> -->

::: {.aligncenter}
![Dry fit of the joinery](/img/resized/box-spine-dry-fit-800.jpg "Dry fit of the joinery")
:::

<!-- TODO: find more in-process pics of the joinery -->

Before glueing up the joints, I prepared the sides to hold their respective hardware. The Raspberry Pi and amps I planned to mount with standoffs, so I drilled small recesses to epoxy them in after the glue up, making sure to position these with enough room that the wiring wouldn't rattle against the vibrating panels. The switches and jacks needed holes drilled through one side as well as recesses, as the side was too thick to screw on the washers that would hold them in place. I dug out the recesses with a chisel. I labelled the jacks and switches using a lettering punch set my dad and I found in his workshop.

<!-- Once your joints are cut and you're satisfied with the dry fit, it's time to get ready to mount the hardware. It's critical to do this before the glue-up as access to both sides of the pieces is needed. There are three parts to this: holes for the jacks & switches, recesses because the wood will be to thick to mount them, and recesses for the standoffs. -->

<!-- Lay the pieces flat with the inward-facing side up and arrange the hardware as it will be mounted, then trace the mounting holes and the outlines of each component on to the panels and label the positions of each component in pencil. Drill a small pilot hole in the centre of each marked jack and switch, then drill the full size _from the outward-facing side_ to reduce tear-out. Using a Brad-point bit or a Forstner bit will also help. Next, dig out the recesses for the jacks & switches using a chisel (or power tools if you prefer). You might also like to label the jacks and switches at this point, while the boards are still flat. I used an old lettering punch set from my Dad's workshop. -->

::: aligncenter
![Lettering on the side with holes for jacks and switches](/img/resized/box-side-lettering-800.jpg "Lettering on the side with holes for jacks and switches"){ style="margin: 0" }
:::

In retrospect, recessing the standoffs wasn't a good idea. I thought it would give more surface area for the epoxy to hold onto while also aligning the standoffs, but it fell short on both fronts. Epoxy seals better to flat surfaces <!-- TODO: check --> and the standoffs didn't really sit in the recesses because the drill bit left a curved surface. The standoffs for the amps seem to be holding up alright, but the Raspberry Pi fell off during transit and I need to find another way to mount it again.

<!-- I mounted the standoffs by drilling small recesses and expoying them in after the glue-up. In retrospect, this isn't a very strong way of mounting them, since it didn't result in a flat surface and the epoxy isn't quite strong enough to hold the heavier components like the Raspberry Pi. I don't really know of a better way to mount these things though, so if you have a suggestion, I'd love to hear it. -->

<!-- <div> -->
<!-- <div style="float:left;"> -->

::: aligngrid
![The sides are too thick to mount the jacks](/img/resized/box-side-too-thick-for-jack-400.jpg "The sides are too thick to mount the jacks")

<!-- </div> -->
<!-- <div style="float:left;"> -->

![Recesses for the jacks and switches dug into the inside of the side](/img/resized/box-side-recesses-400.jpg "Recesses for the jacks and switches dug into the inside of the side")

![Glueing up the first joint of the spine](/img/resized/box-spine-glue-up-400.jpg "Glueing up the first joint of the spine")
:::

<!-- </div> -->
<!-- </div> -->

<!-- <div style="clear:both;"> -->
<!-- Finally, the part where it all comes together: the glue-up. Glue the spine joints together first. If you're a beginner woodworker like I am, you may want to make use of 90° clamps and techniques like filling gaps in the joints with a sawdust and glue mixture. Once the spine has dried, check the dimensions of the side panels and make any adjustments as necessary. Glue one of them on, leaving the other off in order to have access to the inside to mount the hardware. The box is designed to be maintainable after all the glueing is done, but it is _much_ easier to install the components with one panel off. -->

Eventually I did glue and touch up the joints. Because my joinery was imperfect, I used 90° clamps and also needed to fill gaps with sawdust and wood glue. Once these joints set, I cut the panels to the final length then glued the first panel and installed the mounting hardware for the electronics. I left the other panel off until after finally installing all the electronics.

<!-- </div> -->

<!-- ![glueing up the first joint of the spine](/img/resized/box-spine-glue-up-400.jpg) -->

::: alignright
![Conduit pieces](/img/resized/box-conduits-400.jpg "Conduit pieces")
:::

In order to route the connecting wires across the inside top of the spine, some conduit pieces are needed. These can be made from scrap wood by planing one side flat, cutting into narrow slices, and drilling holes through for the wires. Be aware that the wires take more space than it seems and you need to have room for the plugs as well! Glue these at intervals along the inside top of the spine.

# Final Assembly ^[↑](#top){.toplink}^ {#final-assembly}

This phase involved connecting and mounting the electronics, glueing on the second panel, and final touches like sanding and finishing the wood.

![Haptic Box cross section](/img/haptic-box-open-20220204-800.jpg "Haptic Box cross section"){
    srcset="/img/haptic-box-open-20220204-400.jpg 0.5x,
    /img/haptic-box-open-20220204-1600.jpg 2x,
    /img/haptic-box-open-20220204-2000.jpg 2.5x"
}

## Connecting and mounting the electronics

Everything in this phase happened somewhat simultaneously since each aspect informed the others. There was more soldering, but thankfully the layout didn't require any of it to be done in-place since all the connections are either pluggable on one end or attached to removable jacks or sockets. The diagram below (not to scale) illustrates the connections.

![[Connections diagram](/img/meta-circuit.svg)](/img/meta-circuit.svg "Connections diagram")

There was a lot to consider about the placement of the transducers: three of four sides of each panel are fixed, the panels have knots, the weight of each transducer and piezo might have some effect on the sound, and so on. The YouTube channel Tech Ingredients discusses placement of contact exciters on speakers made of free-hanging synthetic panels in [this video](https://youtu.be/watch?v=CKIye4RZ-5k&t=766). Despite the differences in construction (mainly the fixed / free sides), I started with the suggested two-fifths placement, positioning a transducer two-fifths along the width and length, then the pizeo two-fifths from the opposite sides, then adjusted after some testing. I found the transducer and piezo to be very close together at two-fifths so I ended up moving them further apart. I swapped the position of the piezo and transducer for the opposite panel to add some variety.

With the transducers placed (but not yet mounted), I was able to settle on the assorted lengths of wire I'd use to make the connections. Choosing the lengths was non-trivial. As I discovered with the maple box, extra length of wire would rattle against the sides, but the connections needed to be long enough to remove and replace components during maintenance. To solve this, I tied coils of extra length to the conduits mounted on the inside top of the spine. Then I was able to solder the remaining connections.

<!-- Some notes: -->

<!-- - Some multiple connections are displayed as single lines: the runs from the amps to the transducers and piezos are a pair (positive and negative), and the other audio runs have three connections (left, right, and ground). -->
<!-- - The polarity on the Dayton Audio transducers is indicated, and on the piezos assume the centre is positive and the outside is negative (apparently [this isn't a sure thing](https://electronics.stackexchange.com/questions/231460/how-to-determine-the-polarity-of-a-piezoelectric-buzzer) and I'm not sure it matters much, but if you want to change it after it's easy to do so). -->
<!-- - The soft-shutdown button just has to connect to a ground, any ground will do. Mine is mounted directly next to one of the TRS jacks so it's connected to one of their grounds. I also find it really sensitive so it's usually disconnected. -->
<!-- - The 3PDT switches change all components of each input or output audio stream (left, right, and ground). This has the potential to introduce a lot of noise, especially when the switches are in different directions. I'm not sure that this is the best way to do it and I'm happy to take suggestions here. -->

Modifying the USB cable to include the switch was easier than it looked. USB 2.0 (the type this project uses) has four internal connections: two for data (green and white) and two for power (black for ground and red for +5V).[^USB-pinout] I was able to cut the cable in half and splice the switch into the red wire (as well as some extra length to run the connection across the entire box).

<!-- If you're careful and your USB cable is long enough, you can get away with only splitting the red wire and inserting the switch. Otherwise, cut the cable in half, solder connections for the red wire to the switch, then for both red (from the switch) and black to the extra length for the remaining run to where the Raspberry Pi is mounted and then from that to the other end of the USB.[^GPIO-power-input] It's difficult to test these connections using the USB pins, so be careful matching the colours! -->

[^USB-pinout]: See [here](https://pinoutguide.com/Slots/USB_pinout.shtml) for more details on the pinout and [here](https://www.electroschematics.com/usb-how-things-work/) for images.
<!-- [^GPIO-power-input]: It is possible to power the Pi over the GPIO pins, but doing so bypasses some of the Raspberry Pi's power conditioning and is not recommended. -->

<!-- ::: {.aligncenter} -->
<!-- ![USB pinout diagram from [https://www.electroschematics.com/usb-how-things-work/](https://www.electroschematics.com/usb-how-things-work/)](https://www.electroschematics.com/wp-content/uploads/2010/01/usb-pinout.jpg?resize=500%2C328) -->
<!-- ::: -->

<!-- **TODO: cite and double check info about USB spec (esp. re colours)** -->

<!-- While doing this, think about the lengths of the wire you will be using. More length means more clutter inside the box and increased likelihood of rattle, while less length means maintenance will be more difficult. It's a good idea to place the components where they will be mounted (see the next heading) and measure out the wire in-place as much as possible. Keep in mind you can bundle some length by looping it and tying it to the conduits with twist-ties or string. -->

<!-- ## Mounting the electronics -->

Mounting the transducers was straightforward. The Dayton Audio transducers come with pre-applied adhesive which works quite well. I used a thin layer of silicone putty to affix the piezo discs to the panels. This material has the benefit of slightly dampening transients of sudden sounds which would otherwise clip at the preamp, is easy to remove (unlike the wood glue I used on the maple box), and is inexpensive and easy to find. It's sold as ear plugs for swimming or for sound at drugstores; [Mack's](https://www.macksearplugs.com/product/pillow-soft-silicone-earplugs/) is a popular brand but own-brand / no-name options are often available.

![Close up of the mounted electronics](/img/resized/haptic-box-mounted-electronics-800.jpg "Close up of the mounted electronics")

The other electronic components also mounted easily, though there was some finnicky work routing the wires around the standoffs and underneath some of the amps. I'm not sure this is a great solution and there are still some lingering noise issues I have to track down. Regardless, at this point I was getting quite excited because the end of the build was in sight.

## Final glue-up and finishing ^[↑](#top){.toplink}^

![Glueing on the second panel](/img/resized/haptic-box-second-panel-glue-up-800.jpg "Glueing on the second panel")

Back to woodworking. Some time had passed between glue ups and so the spine needed to be pushed out to square during the glue-up. I brought all my clamps to bear on the situation and it wasn't a problem. After the glue set, I put a small chamfer in the edges of the panels and gave the whole thing a light coat of linseed oil (remembering to remove the nuts and washers on the connection hardware). Like woodworkers often say, even a light finish really brings out the natural colouration features of the wood. I was a little worried that it would accentuate the colour differences between the maple and the probably-cedar, but the maple actually darkened nicely and I don't think anything got too yellowy.

![Haptic Box and a plant](/img/haptic-box-with-plant-800.jpg "Haptic Box and a plant"){
    srcset="/img/haptic-box-with-plant-400.jpg 0.5x,
    /img/haptic-box-with-plant-1600.jpg 2x,
    /img/haptic-box-with-plant-2000.jpg 2.5x"
}

# Next Steps ^[↑](#top){.toplink}^

With the box built and ready to make some sound, I started to put it through its paces using the phono jack inputs and outputs. It's quite a good feedback instrument, capable of [noisy excursions](https://sonomu.club/@dried/107758842491601098), [whistling along with birds](https://sonomu.club/@dried/108527786077909901), and more [ethereal tones](https://sonomu.club/@dried/108540784522938978). For the haptic sound process, I needed to get code running on the onboard Raspberry Pi. Documentation of that work is found on [the code page](/works/haptic-box/code.html).
