---
title: Background
parent: Haptic Box
date: 2022-08-17
edited: 2022-09-26
article-class: chicago-style
---

::: contents

### Contents

- [Introduction](#introduction)
- [It must be made by its listener](#it-must-be-made-by-its-listener)
- [It feeds back](#it-feeds-back)
- [It is held](#it-is-held)
- [It continues](#it-continues)
- _[Notes](#fn1)_

:::

# Introduction

[Haptic Box](/works/haptic-box) is a box built by its listener which makes tangible sound affected by how it is touched. It is a broad project without a clear definitional status: not decisively a sound sculpture, instrument, composition, performance, or DIY project. Though it is quite different in shape from much of my previous work, Haptic Box is a continuation (or offshoot or doppelgänger) of many of the topical nebulae that generated them. Here I want to expand on some of these ideal connections as well as some of the material and social contexts alluded to in the [build notes](/works/haptic-box/build.html) and [code notes](/works/haptic-box/code.html) in order to begin to situate some of my conceptual intentions and speculated implications of Haptic Box. This bit of writing is also a meandering, repetitive, and variously (un)polished exercise and pool of ideas for me to return to and clean up. It will change.

My simplistic conception of Haptic Box is as a sound sculpture with three defining characteristics: its sound is tactile, shaped by an algorithmic feedback process, and it must be made by its listener. The tactile sound is in the form of low frequency tones (below about 300 Hz) which emanate through the body of the box, driven by contact exciter transducers. These tones are generated not by a fixed composition but by feedback from piezoelectric pickup transducers mounted on the same surface. To keep the feedback in the tactile frequency range, it is run through an algorithmic filtering and limiting process on a small computer inside the box. Finally, the piece is encountered as a description (with the included proviso that it should be self-constructed), and not as an encounter with a physical object or a score.

<!-- still don't love that last sentence -->

As they relate to my broader project of creating opportunities for pointed experiences of embedded interactions with nested and interconnected amalgams, these three aspects are themselves fairly tightly interlinked and co-constitutive. Touch, for example, is a very acute point of interaction between a body and its environment which can already itself present feedbacks around questions of their boundary and co-constitution; a vibrational feedback process pinpoints this and invokes temporal and socio-aesthetic dimensions further complexified by the user-listener's social-material-historical relationship to having made the box (and having found its instructions online, having gathered its materials, shaped them...), which in the first place requires a great deal of touch.[^we] How these interests conglomerated into the particular form of Haptic Box (instead of another quiet switchcraft performance piece, for example) has more to do with my personal artistic, social, and material circumstances.[^switchcraft]

[^we]: I wrote this page seemingly unproblematically using the reductive designations "the user" and "the listener." Obviously effects vary for each person to experience the piece, and prescribing such clear outcomes for user-listeners of the piece is both inaccurate and potentially dangerously co-optive. However, I take this gamble in my approach to thinking about experience because it's more realistic than to assume that there are zero commonalities between my experience and someone else's. Speculatively imagining what an experience can do for a hypothetical encounter is a way for me to attempt to account for my effects on others. Importantly, speculation does not end at simply deliberating and performing an action, it also observes the results of the action to inform future speculations. See [What's the Trouble](/whats-the-trouble) for more on speculation. For more on the subsuming effect of "we", see Elin Diamond, “The Violence of ‘We’: Politicizing Identification” in _Critical Theory and Performance_, edited by Janelle G Reinelt and Joseph R Roach (Ann Arbor: University of Michigan Press, 1992),390–98.

[^switchcraft]: For more about quiet and switchcraft, see my MMus thesis: Riedstra, David. “Mathesis and Technicity in ❙■▲▬●,” March 2015. [https://www.academia.edu/12007070/Mathesis_and_Technicity_in_](https://www.academia.edu/12007070/Mathesis_and_Technicity_in_). Also available [here](/downloads/Riedstra_-_Mathesis_and_Technicity.pdf).

# It must be made by its listener

The self-constructed aspect of Haptic Box reflects a line of thought oriented toward the skill of interacting with an environment and the transduction from process to object that can be occasioned by those interactions. My previous web-based sound work _[What's at Hand](/works/whats-at-hand)_ hinges on the same line of thought. Users are asked to play sound quietly from a portable personal device such as a smartphone, mixing them to a level that is audible to themselves but doesn't disturb others in the vicinity. Through aesthetic attention to unfamiliar intentions (ie, what the score asks them to do) and sounds in combination with familiar objects and controls, I had hoped to engage an experience of active and necessary participation in socio-cultural-acoustic situations, bringing out habituated and intentionally learned social and technical skills. When I played a late version of the piece in some of the libraries around the University of Leeds campus, I found the environment's presence in my volume-mixing actions much more pronounced than I had expected. While I knew consciously of the effect the sound was potentially having – and even imagined feeling the 3-dimensional shape of the sound – the experience of listening to the sound and manipulating its volume became aesthetically focused on taking in the environment with my actions / sounds in it.[^aesthetical] The sound-actions took on a funny status of partly-me, partly-environment: I was responsible for playing them and for their particular volume, but listened to them as sonic features of the room whose effects I needed to respond to. Listeners to the piece who aren't as familiar with its sounds as I am will likely have an even more outwardly-bound experience, discovering the nature of the sound at the same time as all this other negotiation.

[^aesthetical]: As I mention in [a footnote](/works/common/program-note.html#fn1) on the program note to _Common_, I'm using the word "aesthetic" to somewhat naively refer to focused and self-conscious taking in of experience for its own sake. I eagerly invite interpretations that allow for a broader scope of "aesthetic," such as the various scenarios Yuriko Saito describes in _Everyday Aesthetics_. I am also vaguely aware of some terminological debate around what "aesthetic" means (and separately, what is "aesthetics") but I am avoiding cracking that particular nut at this moment. Yuriko Saito, _Everyday Aesthetics_ (New York: Oxford University Press, 2007), [https://doi.org/10.1093/acprof:oso/9780199278350.001.0001](https://doi.org/10.1093/acprof:oso/9780199278350.001.0001).

Later I wrote myself a study for double bass. Though it wasn't initially imagined as a study, it was nevertheless centred on skill. I wanted to play (for myself, not as a performance) in the sound world of viol consorts and Martin Arnold's _[Aberrare (Casting)](https://collectionqb.bandcamp.com/album/martin-arnold-aberrare)_, the timbres and flow of which I've been enamoured with for years. (Coincidentally, this was around the same time that I began having ideas for Haptic Box.) With the very practice-research idea of thinking through doing in mind, I called the piece [_Table_](/works/table): it would be a surface at which I could sit, spread out materials, and think about things like how instrumental skill relates to affective sound worlds and the effects of inward-facing practices by engaging with them. On the advice of a close friend I read the first chapter of Sarah Ahmed's _Queer Phenomenology_, "Orientations toward Objects," in which tables recur as a pivotal figure Ahmed uses to analyze the gendered history and orientation of phenomenology and philosophy more broadly.[^ahmed-queer-phenom] In this chapter, patriarchical gendering manifests in the bracketing of contexts through a tendency toward universals. Examples include phenomenologists (men) meditating on "the body" without problematizing or acknowledging their own body, or focusing on "the table" only thanks to the privilege of being able to orient away from domestic contexts like childcare and cleaning. Ahmed points out that by perpetuating similar orientations, this behaviour shapes the occupation of philosophy around the bodies and objects which occupy it and can also shape those bodies and objects (when, for instance, the writer develops tendinitis, a situation I acutely sympathize with at the moment.) In other words, objects shaped for work shape the work that they do, and bodies, objects, occupations, and spaces interact in ways which afford and inhibit behaviours and continually mutate as they carry forward histories of previous and ongoing interactions. _Table_ then is both a side effect / result of a certain tangle of histories (my relationship to Arnold and his music, my ability to practice regularly having recently moved to a place which  afforded it, the physical state of my body and my instrument which is affected by far and recent histories of practice tendencies, which are in turn embedded in their own contexts...) and something that feeds back into them (through the particular techniques it focalized for me to practice and ingrain into my body, it leading to Jennifer Walshe's _This is Why_ via its once-removed intimation of embodied experience, its becoming a catalyst for my friend to recommend reading Ahmed and from there through through to me hunched over a notebook in the PGR room of the University of Leeds's music building scribbling out these words, which will then inform some later revision of this text which might even register on some level with you).[^walshe-this-is-why]

[^ahmed-queer-phenom]: Sara Ahmed, "Orientations Toward Objects" in *Queer Phenomenology: Orientations, Objects, Others* (Durham, NC: Duke University Press, 2006).
[^walshe-this-is-why]: Jennifer Walshe, *THIS IS WHY PEOPLE O.D. ON PILLS*, 2004, solo performer, [https://www.cmc.ie/music/why-people-od-pillsand-jump-golden-gate-bridge](https://www.cmc.ie/music/why-people-od-pillsand-jump-golden-gate-bridge).

Self-constructing _Haptic Box_ came to be a way to encounter this inter-constitutive multi-milieux embeddedness in a very literal sense while still tying it to the rarefied art experience. Whereas that embeddedness for _Table_ is only available to a listener / third party once removed, as my own embeddedness willingly recounted and represented in a document such as this one, or as the reader's / listener's content bracketed by the score's or recording's self-interest, building _Haptic Box_ requires a negotiation / interaction with one's own environments as well as my own. Materials must be gathered, skills learned, the form designed and through this process the builder continually puts their body in salient relationships with its environments, histories, materials, and work in patterns that are shaped by them and that shape them. These negotiations are also negotiations with my entangled practice, represented by _Haptic Box's_ existence at all, in its particular form, and through the reflexive language used in its log-documentation-score as well as that document's situation on my personal website. These are profoundly tied up in the experience with the feedback composition: taking it in through touch, sight, movement, smell, and possibly / probably also sound, the builder-user-listener (as I imagine them, anyway) re-encounters the particular acoustic properties of the object they built along with the tactile-embodied memory of building it while engaging in the aesthetic attention to their present interaction with it.

Building _Haptic Box_ also enables an empirical encounter with a strangely quotidian transmutation (?) between object and process. Reflecting on the Ahmed chapter and _Table_ while overthinking overthinking artistic practice (or trying not to) led to the idea that similar to the way in which objective attributes feed back into occupations, art pieces are like dust or [debris](/debris.html), side effects of a practice. _Table_ is an incidental product of my overlapping practices as composer and bassist. Like workplace repetitive injuries, skills accrue and objective dimension. Strengthened muscle groups, motor habits, and neural pathways are physical embodiments of those effects. The built object _Haptic Box_ is a similar side-effect of intersecting practices: in my case of artist, coder, maker, privileged with time and ability; in a listener's case something similar. In each case, the side-effect maintains objective and processual dimensions. The objective aspect is the "thing" that can be pointed to that individuates itself from its generative practices (the piece, the skill, the box). The processual aspect is that thing's continued perpetuation as it plays into and is affected by its contexts.[^objective-process-from-massumi] A skill may be more clearly processual than a box, as it is continually shaped by its volume of exercise. The panels of my box are the history of sun and water and photosynthesis probably half a century ago at least and the land long before that and a capitalist-driven strip cut operation and a mill and various tiers of government "cooperation" on things like rail and highway infrastructure and someone wanting to redo their basement so they bought a two-by-eight of some cheap softwood for the bannister of the exterior stairwell and doused it in shellac and left an offcut in the mud room and a plane I bought from Home Hardware and a slightly better plane I bought from the Aberfoyle antique market while friends from the city were visiting (we were lucky it was open that weekend) and a lot of sweat on my part and a plane from Pearson and a train from Gatwick to where they currently sit in the Pelican case which I use as a dining table in my cheap flat in Leeds's Hyde Park. While those panels are busy supporting a critical moment in my artistic practice, wood from the same board shaved off only a millimetre away supports my sister's family's compost after it had been used by their chickens, soon to contribute to land and photosynthesis once again. Spending time shaping and being shaped by material through making with it and living with the result (?) is a way to experience its processual nature. Focally aesthetically engaging with it provides an opportunity to feel the tension between objective and processual modes of material and relate those to social, acoustic, and other milieux.

[^objective-process-from-massumi]: The image of matter as process was not an entirely new discovery in this moment, having been conditioned by my earlier encounters (for example, with Brian Massumi's *Semblance and Event* and Donna Haraway's *Staying with the Trouble*) which I will explore in more depth elsewhere. Ahmed's chapter was especially significant because it put this transduction in terms that registered as more concrete to me. Despite their lasting influence on my thought, Massumi's and Haraway's ideas registered as "in principle" whereas while reading the Ahmed I was able to see the process in practice.

# It feeds back

Though not the only reason for my use of feedback, Ahmed's ideas implicate feedback in profound ways. Her description of bodies and objects and work shaping each other is also a description of feedback interactions within and between various milieux: material, social, historical, economic, environmental, and so on. An orientation that acknowledges its context is also one which engages with its situation in that context as co-constituent in ways that skillfully interact with the feedback instead of behaving linearly without thought for effects on or by one's context.

<!-- link skillfully to skill / resonance page -->

While I find the conceptual connection between feedback and entanglement compelling, the feedback in Haptic Box has its origin in practice and experimentation. During the initial coronavirus lockdown I sank myself into digital audio as the most practicable way of continuing my practice within the limits of a small Toronto apartment in that particular moment of global uncertainty. Among the new techniques, small scraps, and glitches (some of which directly ended up in [What's at Hand](/works/whats-at-hand) and others in various sound practice logs embedded in like-minded online communities such as [vis.social](https://vis.social/@driedstr) and [sonomu.club](https://sonomu.club/@dried)) several connections to feedback emerged. One was remembering an older Pure Data patch that simply connected stereo microphone inputs to speaker outputs and phase-inverted one of the channels. Running it on my MacBook Air or my Thinkpad (both of which feature closely positioned microphone inputs) created a feedback instrument which could be played by altering the phase relationship through hand movements in the physical feedback path through the air. Experimenting with the instrument again during lockdown, I felt that it offered an engaging experience of material interrelation between body, instrument, and sound. I discovered it is very similar to Hans Koch's 2003 _[Bandoneonbook](https://microphonesandloudspeakers.com/2017/03/03/bandoneonbook-hans-w-koch/)_, and though I don't remember exactly, his use of the keyboard to filter the feedback may have been an influence for me to consider doing the same.[^bandoneonbook] Serendipitously I built a version of Cat Lamb's *secondary rainbow synthesizer* which uses a similar filtering technique. Lamb's version filters microphone audio from outside the performance space to create a harmonic shadow to the ensembles more active musical activity. My [version](https://vis.social/@driedstr/104767285091601683), created from a misinterpretation of that basic description, filtered feedback within the same room using a MIDI keyboard to control the number, pitch, and Q of the bandpass filters.[^secondary-rainbow] Other similar experiments during this time involved using pitch analysis to isolate prominent frequencies in the incoming audio and [replay](https://vis.social/@driedstr/104790487865481996) them as synthesized sine tones in a sort of fake feedback, filtering feedback to create [pleasant crackles and pops](https://vis.social/@driedstr/104921661539110695) in the incoming audio, and recreating hardware synthesizer modules such as the [4ms Spectral Multiband Resonator](https://vis.social/@driedstr/105165663048582001) and the Serge Resonant Equalizer. These feedback experiments persisted through our move from Toronto to Guelph, intersecting with more recreations of classic synths, [phsyical analog hardware](https://sonomu.club/@dried/105551192507414882), [double bass playing](https://sonomu.club/@dried/106263238459667237), and eventually [transducers on boxes](https://sonomu.club/@dried/105635427372879562) and [purpose-built boxes](https://sonomu.club/@dried/105799357004933933).

[^bandoneonbook]: Cathy van Eck,  Bandoneonbook by Hans W. Koch,  *Between Air and Electricity* (blog), March 3, 2017, [https://microphonesandloudspeakers.com/2017/03/03/bandoneonbook-hans-w-koch/](https://microphonesandloudspeakers.com/2017/03/03/bandoneonbook-hans-w-koch/).
[^secondary-rainbow]: Catherine Lamb, “Prisma Interius V Example Score,” 2017, [https://www.sacredrealism.org/media-files/LambExampleScores/Lamb_PrismaV_Aug21_example.pdf](https://www.sacredrealism.org/media-files/LambExampleScores/Lamb_PrismaV_Aug21_example.pdf).

::: alignright
![Four different op-amp configurations: voltage copier (buffer), non-inverting amplifier, inverting amplifier, inverting buffer. Note that in each case the output is sent back into the inverting (-) input. [Full size](/img/basic-op-amp-circuits.png).](/img/basic-op-amp-circuits-400.png "A circuit diagram showing four different op-amp configurations"){
    srcset="/img/basic-op-amp-circuits-800.png 2x,
    /img/basic-op-amp-circuits-1200.png 3x,
    /img/basic-op-amp-circuits-1600.png 4x"
}
:::

Study of these various instruments and the techniques of electronic music in both digital and analog forms revealed the pervasiveness of feedback in interacting with flows of electricity, samples, and acoustic vibrations. Digital filter algorithms require feedback in order to affect the rate of change of a stream of samples. A simple one-pole low-pass filter, often used as an example for sample-level DSP instruction, can be constructed by delaying the signal by one sample, reducing its amplitude, and mixing it in with the incoming signal.[^faust-filter] More complex digital filter algorithms vary the delay length and amplitude reduction using values generated by mathematical functions which account for sample rate, filter frequency and cutoff, but the principle remains the same, and processes for reverb and other time-based effects make use of it as well.[^filter-algos] While feedback is not strictly necessary for analog filters, which can be accomplished by simply passing the signal through a capacitor, more complex circuit designs are typically used, often with variable resonance, which does require feedback. By varying the amount of signal fed back from the filter's output into its input, the amount of resonance can be increased until the filter self-oscillates at roughly the cutoff frequency. Other resonant circuits use a similar principle. Feedback is also used in other even more utilitarian analog contexts, the most notable of which is the collection of techniques for using operational amplifiers and transistors. Feedback by way of connecting the op-amp's output to its inverting input is used to self-regulate functions like signal buffering, amplification, and phase inversion.[^horowitz-and-hill] 

[^faust-filter]: See for instance the "One-Pole Filter" example in the FAUST documentation, given by the FAUST code `process = +~*(a1)`: [https://faustdoc.grame.fr/manual/syntax/#recursive-composition](https://faustdoc.grame.fr/manual/syntax/#recursive-composition)
[^filter-algos]: Examples of these algorithms can be found on [musicdsp.org](https://www.musicdsp.org/en/latest/Filters/index.html), and tutorials associated with DSP languages like SuperCollider and Pure Data often give useful introductions as well.
[^horowitz-and-hill]: Paul Horowitz and Hill Winfield, _The Art of Electronics_, 3rd ed. (New York: Cambridge University Press, 2016), 225–7; _SDIY Class #9 - Intro to OpAmps_, accessed August 30, 2022, [https://youtu.be/watch?v=yQlSs3PObyY](https://youtu.be/watch?v=yQlSs3PObyY).

So feedback was already "in the air," and in order to enable the feeling of affecting a material-musical process through touch while immediately feeling those effects, I needed to put it into the material. Though there exist other options for correlating the materiality of a listener with a generative sonic process (I had previously explored triangulation through WiFi antennae on smartphones in [802.11](/works/802-11), gyroscopic and visual sensors also come to mind), they all involve a step of analytic redirection. Having the listener-user affect the vibratory process by touching it injected them into its feedback loop, rendering their effects on the process direct and material. Keeping the vibration frequencies in the tactile range means that they *must* be touched in order to be taken in, creating the possibility of an immediate experience of entangled intra-action I chase in all my work.[^barad-intra-action]

Sometime during the construction of Haptic Box I discovered the work of Alice Eldridge, which quickly became a noteworthy inspiration. Eldridge is an artist working with feedback in systems heavily influenced by evolutionary ecosystemics and her work as an bioacoustician.[^acou-eco] Her approach to experimental luthery as "speculative faction," interpreting the world through making things which then become forces affecting the world, aligns with my reading of objects as feedback processes through Sarah Ahmed and fits with my emerging thoughts on speculation and process [debris](/debris.html).[^speculative-faction] Similarly, to me her evolutionary generative systems modelled aspects of Donna Haraway's *sympoiesis* and provided a timely key to the problem I soon faced.[^sympoiesis]

[^barad-intra-action]: Barad, Karen. *Meeting the Universe Halfway: Quantum Physics and the Entanglement of Matter and Meaning*. Durham, NC: Duke University Press, 2007. [https://doi.org/10.1215/9780822388128](https://doi.org/10.1215/9780822388128).
[^acou-eco]: Which is to say that Eldridge is not an *acoustic ecologist* striving to preserve "natural" acoustic environments, but rather that she gathers and analyses ecological acoustic data in order to study biodiversity.
[^speculative-faction]: Alice Eldridge,  "Ecosystemics and Ecoacoustics: creative coding for speculative faction & (re)sensoring empiricism," *Electric Spring 2019*, CeReNeM, May 31, 2020, video, 4:45, [https://www.youtube.com/watch?v=eNCqoNxzY3Y](https://www.youtube.com/watch?v=eNCqoNxzY3Y).
[^sympoiesis]: "Sympoiesis is a simple word; it means 'making-with' ... Sympoiesis is a word proper to complex, dynamic, responsive, situated, historical systems. It is a word for worlding-with, in company. Sympoiesis enfolds autopoiesis and generatively unfurls and extends it." Donna J. Haraway, "Sympoiesis: Symbiogenesis and the Lively Arts of Staying with the Trouble," in *Staying with the Trouble: Making Kin in the Chthulucene*, Durham, NC: Duke University Press, 2016.

While it was useful to have the form of the piece sorted out, I needed to determine the algorithmic filtering process.[^butterfield-quote] Though to some extent I could rely on the user's tactile modulation to provide change, it wasn't enough to keep the vibrational material interesting enough to warrant continued interaction. At the same time, a deterministic process seemed contradictory to the kernel of ongoing evolving-with that Haptic Box encapsulates. I needed a system with its own built-in change, but as with gyroscopic or visual sensor-based interactions, a system based on discrete analytical movements and thresholds would be too clunky, indirected, and forced. As I was experimenting with these types of systems, I [discovered](https://sonomu.club/web/@dried/108532085662920318) a misunderstanding I had had of the word "hysteresis." Thanks to its use in interfaces, I had thought of hysteresis as a cooling-off period before some element becomes open for interaction or change again. While this behaviour is covered by the term, the broader definition I found on Wikipedia as "the dependence of the state of a system on its history" was enlightening.[^hysteresis] Instead of defining a set of zones and thresholds for the system to deterministically move through, the character and gradual evolutionary unfolding needed to come from the system's own definition, as in Alice Eldridge's elegant evolutionary systems pieces.[^filterscape] The "organic" quality of change in the tactile sound of Haptic Box would grow from its continual reaction to its past states and the way its audio feedback interacts with the material world in which it's embedded: a process memory that plays out similar to the memory Ahmed sees tools and users investing in each other.

Through experimentation I discovered two ways of building memory into the process (which I describe in more detail on [another page](./signal-processing.html)) through reflexive analysis of the ongoing process parameters. One of these is a continuation of the types of process I used in [Pathside Box](/works/pathside-box.html) and the Birdies section of [What's at Hand](/works/whats-at-hand): the slowly roaming bandpass filters which regulate the audio feedback reduce their speed to linger around more resonant frequencies. The changing relationships between the positions of the filters also has an effect on the apparent resonance, as overlapping filters will generate a "false" resonance when their outputs are summed. Since this behaviour might eventually result in the filters clustering around the same position, another reflexive process was needed to counterbalance its tendency toward stasis.

[^butterfield-quote]: "It's nice to have a form, but what about the content?" Christopher Butterfield, “Untitled Lecture” (Lecture, Ostrava New and Experimental Music Institute, Ostrava, Czech Republic, August 2017).
[^hysteresis]: Wikipedia contributors, "Hysteresis," _Wikipedia, The Free Encyclopedia_, [https://en.wikipedia.org/w/index.php?title=Hysteresis&oldid=1108863922](https://en.wikipedia.org/w/index.php?title=Hysteresis&oldid=1108863922) (accessed September 30, 2022).
[^filterscape]: Alice Eldridge and Alan Dorin, “Filterscape: Energy Recycling in a Creative Ecosystem,” in Applications of Evolutionary Computing, Lecture Notes in Computer Science (Berlin, Heidelberg: Springer Berlin Heidelberg, n.d.), 508–17, [https://doi.org/10.1007/978-3-642-01129-0_57](https://doi.org/10.1007/978-3-642-01129-0_57).

My ongoing casual experimentation in analog synthesis provided an inroads to a useful discovery: the analog shift register. When paired with feedback, the behaviour of the shift register mimics that of a neuron, "learning" from its own memory while responding to new input. This insight comes from influential Eurorack designer Andrew Fitch's [Squid Axon](https://www.nonlinearcircuits.com/modules/p/squid-axon), a circuit implementation of the behaviour of giant squid axons which uses analog shift registers with feedback.[^squid-axon] In the context of the kinds of Eurorack feedback patching I was experimenting with, a feedback shift register provided the kind of behaviour I was looking for: self-regulating but unpredictable, chaotic but not random.[^neuronal-patching] Plugging in a shift register to the bandpass movement in the Haptic Box SuperCollider patch ensured that the self-organizational behaviour of the tactile feedback continued its slow evolution in its own way, responding to the environment, the user's inputs, and its own process memory.[^olarte-benjolin]

[^squid-axon]: In this case, "analog" refers both to the data stored in the register (which are continuous values, as opposed to a digital shift register which stores binary on and off states) and to its microcontroller-free implementation. Specifically, the Squid Axon implements the Hodgkin-Huxley equation as described in Tetsuya Matsuzaki and Masahiro Nakagawa, “A Bipolar Logistic Chaos Neuron and Its Hardware Implementation,” *Electronics & communications in Japan. Part 3, Fundamental electronic science* 86, no. 11 (2003): 46–56.
[^neuronal-patching]: I took considerable influence from the patching style described by the YouTube channel *[La Synthèse Humaine](https://www.youtube.com/watch?v=MnYkqlSIr_I),* a Serge-inspired style of feedback patching which seeks evolving self-regulating systems.
[^olarte-benjolin]: I'm indebted to the work of Alejandro Olarte, whose [SuperCollider implementation](https://scsynth.org/t/benjolin-inspired-instrument/1074) of Rob Hordijk's Benjolin provided an example of shift registers provided a necessary object of study for my own build.

Feedback thus provides an integral component of various aspects of Haptic Box. Its vibratory haptic audio process is feedback in the usual sonic sense; the processing which entangles itself in the audio feedback by regulating it does so with feedback mechanisms in its ongoing parametric evolution and in the signal filtering it performs; the project itself is a slow feedback loop by virtue of gathering its builder's history and context in the form of the box object and presenting them back to affect the builder through future encounters. While none of these artificial forms constitute intelligence, feedback may nevertheless be a useful tool for deconstructing the relationship between intelligence, algorithms, and what might appear to be simple mechanical processes. Feedback brings out the salience of environmental entanglement in these processes and smoothes out distinctions between object and process, individual and network, and analysis and intuition.

<!-- There is a lot to dive into here, probably for a separate page. Transduction might be necessary for feedback. Analysis as a form of transduction. The ASR as exmplary of analysis, then compared to sampling and DSP... Internal feedback in ASR: what is transduction of a float value -- does mixing it with the external input constitute transduction? Feedback necessarily must return different otherwise it's not feedback, it's just static. Return of the different. -->

# It is held

Placing the musical material of the piece in the tactile register was an elegant way to effectively require involvement in the outcomes of the piece's vibrations in order to experience them at all.[^soft-must] The sound must be taken in though touch, but because it plays out as feedback on a material surface, the touch changes the nature of the vibrations while trying to sense them (additionally but not exclusively due to the behaviour of the filtering algorithm changing based on the produced sound). This requirement produces a dynamic similar to that of my quiet concert compositions, in which sitting in the audience in order to hear the performance means probably being louder than it, and thereby viscerally entangling an individual or group of listeners' presence with the performance. Whereas the quiet performance situation changes the acoustic outcome in a social sense, creating felt tensions which make apparent the social contract of concertgoing, the tactile feedback plays out on a material level.[^quiet-performances] Handling the Haptic Box affects the ongoing process performed by the filtering, whereas the quiet concert performers are arguably minimally affected by sounds which would be relatively much louder to the audience. Moreover, the terms of entanglement afforded by touch are primarily material, not social: the acoustic feedback is altered through a change in tension caused by fingers pressed against the vibrating wood panel, there are no other listeners to form an audience-body with. Nevertheless, in both cases the embodied nature of listening affects what is listened to, enabling a similarly embodied sense of engagement with the social-material-acoustic situation.

[^soft-must]: This "must" is soft: I imagine -- speculate -- that the haptic vibrations are absolutely silent and try to build the piece that way, writing the description of the piece in this paragraph and even in the piece's title to point to tangible vibration as its -ness, but as John Cage discovered there are no real silences. The incidental sounds of the box rattling against the desk or of the haptic listener's shirt rustling or of the box's internal wires shaking might be considered [debris](/debris.html), excess of the main process, noise. Compare: art as a byproduct of artistic practice, Grosz' art as excess in *Chaos Territory Art*, and Migone's treatment of Lucier's stutter, Beckett's *Not I,* and Cagean and non-Cagean silences in Christof Migone, _Sonic Somatic: Performances of the Unsound Body_ (Los Angeles: Errant Bodies Press, 2012).

[^quiet-performances]: For more on quiet, see the note to [Common](/works/common) or my MMus thesis "Mathesis and Technicity in ▲■❙●▬" [here](/downloads/Riedstra_-_Mathesis_and_Technicity.pdf). Riedstra, David.  Mathesis and Technicity in ❙■▲▬●,  March 2015.

The body of Haptic Box's tactile-listener is further embedded in the experience by way of their having built the box.  While taking in "the piece itself" as a sound sculpture or composition, the user's experience is overloaded with the experience of building. Their touch does not discover a new object but rather traverses a familiar one, one which they have spent a considerable amount of time shaping and whose materials they gathered. Simultaneously, the vibrations and their framing as an artistic object invite exploration and sustained, considered intake. This brings the listener's body into the the piece as a formative component, the experience would be fundamentally different were the box built by someone other than the listener. The piece and its experience are inextricably tied up in the builder's body and history, their access to materials and time, and all of the contingencies of those materials and those periods of building (and of discovering the piece and learning what was needed to build it and...). This entanglement makes the distributed agency of the piece acutely tangible.[^distributed-agency]

<!-- Exploration (3rd sentence) could link to discovery wrt pathside box -->
[^distributed-agency]: It's a bit of an oxymoron to locate or individuate "a" distributed agency, but I guess it's the same thing with saying "a" box which is really a momentary gathering of pieces of wood, glue, silicon, etc. Distributed agency ties in to distributed cognition, and I guess I'm dancing around a distributed objectivity or materiality here. A more fleshed out version of this bit might loop in N Katherine Hayles' *Unthought*, Haraway's *Staying with the Trouble*, 5E cognition, and other relevant writing.

My approach to thinking tactile experience draws on Yuriko Saito's aesthetics of the everyday, a holistic perspective which advocates for a more sensually-attuned encounter with quotidian acts like food preparation and socializing.[^saito] Saito applies a definition of "aesthetic" which does not limit itself to experiences of art or conventional beauty, instead including potentially any experience. "Aesthetic" then is an aspect and not a type of experience.[^aesthetic-massumi] What this means for Haptic Box is that though the sound sculpture might seem to be framed as the aesthetic object, in fact the aesthetic scope is much broader. Seen as a self-performed text score, the construction of the box becomes part of that experience as well, fulfilling Saito's imperative to appreciate mundane tasks and tools. However this text score is not very well defined, neither in its textual boundaries nor in the boundaries of the performed action. These porous boundaries, which enmesh my life into the performance and both of those into the listener's life, allow the everyday and the rarefied to mingle.

<!-- Does the mingling in the last sentence of this para dissolve this binary or reinforce it? -->

[^saito]: Yuriko Saito, *Everyday Aesthetics* (New York: Oxford University Press, 2007), [https://doi.org/10.1093/acprof:oso/9780199278350.001.0001](https://doi.org/10.1093/acprof:oso/9780199278350.001.0001).
[^aesthetic-massumi]: Aesthetic as an aspect and not a type of experience figures in the radical empiricism of Brian Massumi, who describes events (which is to say, experience) with two inter-constitutive dimensions, relational and qualitative, later saying “the relational/participatory aspect of process could fairly be called political, and the qualitative/creatively-self-enjoying aspect aesthetic.” Brian Massumi, *Semblance and Event: Activist Philosophy and the Occurrent Arts*, ed. Erin Manning (Cambridge, MA: MIT Press, 2011), 12.

Saito's illustrations heavily influenced how I think about interacting with objects, especially tools. She describes the particularity of multisensory aesthetic experience of everyday objects with the example of using a knife:

> The aesthetic value of a knife consists not only of its visual qualities, but also of
> its feeling in my hand, determined by its surface texture, weight, and balance,
> but most importantly by how smoothly and effortlessly I can cut an object
> because of the material, shape, length, texture, and weight of the blade and
> handle. The appreciation here is not simply directed toward the fact that the
> knife functions well; it rather concerns *the way in which* all its sensuous aspects
> converge and work together to facilitate the ease of use.[^saito-knife-quote]

The aesthetic dimension of this experience enmeshes the knife's physical properties, those of the user's body, the user's conscious use of the object (intention, cultural knowledge, technical facility), and the use's embodied feel (that elusive character of the unfolding texture of the moment's process). Use's knot of entanglement reveals the interplay between the environments proper to these aspects, allowing the user to feel the play of their involvement in its mesh.

[^saito-knife-quote]: Yuriko Saito, *Everyday Aesthetics* (New York: Oxford University Press, 2007), 28, [https://doi.org/10.1093/acprof:oso/9780199278350.001.0001](https://doi.org/10.1093/acprof:oso/9780199278350.001.0001).

Implicit in this description is the timbre afforded to the experience by familiarity, which invokes the embodied and relational history of the different parties and the particularity of the experience in its unfolding process. The memory of previous experiences wrapped up in familiarity is embedded in the entire body: conscious recollections, repeated movements leading to muscle strength or strain, textures that find their way to the same point on a fingertip. The particularity of the experience plays out as these relationships change over time, for instance as tendons become inflamed from repeated use or grip wears the hilt of the knife smooth. The way these unfold in the familiar aspect of an aesthetic experience is an attuning to becoming with objects.[^kin-objects]

[^kin-objects]: I want to relate this to Haraway's making kin in order to draw out the processual aspect of material, the embedded aspect of objects, and the distributed aspect of agency. Being a custodian of the objective moment of material is to make kin with objects.

<!-- (This making kin with objects engages with a smooth continuum of life and material which I like but is probably beyond me and out of scope) -->

The way in which sensuous aspects of a tool converge into a feeling of familiarity figures in my web scores *[What's at Hand](/works/whats-at-hand)* and *[Revelling in Mists of Constellations of Pine Points and Waltzes](/works/revelling)*. Both of these works invite the listener-user to use their personal device (smartphone, tablet, or laptop) to play their sounds in specified settings. In *What's at Hand*, familiarity with the device parallels familiarity with the social situation the user's making sound interacts with. Through making the sound, the user-listener probes their embeddedness in the social-acoustic setting, and that probing is the exercise of relating social, embodied, and acoustic skills. More than an icon, the personal device becomes a channel through which the probing takes place. The exercise of the social-acoustic-judgement skill is materially manipulated through interactions with the device which contribute their own complex entangled familiarity.

In *Revelling*, the experience of familiarity abstractly turns in upon itself. In the midst of a chaotically loud lockdown in Toronto's east end I tried to make a piece to be played from a cell phone that would be as tactile as it was audible. While I justified this tack in terms of touch as the meeting of a body with its own otherness, a subject-object that finds its soul at the intersection, I was also trying to find a way of making something to hold on to in a sonically and vibrationally noisy environment.[^mmp-serres] The familiarity of my apartment which normally afforded (among other things) the ability to put aside interruptions and focus was itself interrupted. The tactile music I was trying to create was a way for me to continue creating in a familiar medium and, equally importantly, restore some sense of groundedness to my situation. This music would have been escapist in the sense of listening to loud music through headphones on your bed as a teenager to block out time and make sense of youthfully intense emotions, but it would have done this relationally, referring to the chaos outside of the musical-vibrational world of the piece by directing focus inward to its relative stability.

[^mmp-serres]: Michel Serres and Marcel Merleau-Ponty both find something special about points of self-touch. Merleau-Ponty describes them as avenues for encountering the body as both subject and object, both other and self. Serres describes them as locii of the soul: "I touch my lips, which are already conscious of themselves, with my finger... The I vibrates alternately on both sides of the contact, ... The mouth touching itself creates its soul and contrives to pass it on to the hand which, clenching itself involuntarily, forms its own faint soul and can then pass it on, when it wishes, to the mouth, which already has it." Michel Serres, *The Five Senses*, translated by Margaret Sankey and Peter Cowley (London: Continuum, 2008), 22-23.

The point of engaging with familiar objects in these three pieces was not to break the familiarity in order to uncover the sensuous surface of the raw materials of the familiar object, but to let that familiarity colour and shape the experience. Interactions with the sensuous surface of the object are never raw anyway; they are mediated processes informed by variances in bodily shapes and histories and embedded in environments. Drawing aesthetic attention to a familiar tool or technique invests in its process (the user's history of past interactions, the tone of the present carrying on, and [ideas of a future](/whats-the-trouble)) and entangled relations to the environments in which the process plays out.

The familiarity invested in Haptic Box is not a result of its prior use as a tool (though it has that option), but rather of the user's having built it, resulting in subtle but important differences to the flavour of familiarity. Being the object's maker means that the user has has a relationship with its materials that could be described as formative. The user has determined the object's physical shape through close and sustained encounters with its materials, and the resulting familiarity of touch is informed by this history. This rough patch here is from tearout on the day I didn't sharpen the plane enough, I remember cutting these box joints and filling the gaps with sawdust and wood glue, that knot really gave me a hard time. These material changes are indices of past encounters with the material, pieces of oneself left in its shape and what is now its surface.[^serres-scatter] Encountering them through touch becomes an explicit point of contact for the entanglement they continue to enact in their continued returning, highlighting effects like a feeling of responsibility and self-criticism of one's handiwork.[^saito-responsibility] The familiar touch thus recognizes the material of the box as a process, the borders of its would-be states made blurry by the work of having shaped them, tangling its flow with those of the body, the sound, and the digital audio process.

<!-- there's a bit to be written here about how this enables a speculative living-with of the object which is related to responsibility -->

[^serres-scatter]: Serres writes that tools are "scattered limbs dispersed throughout nature, technological objects, thus born. The tool doesn’t extend the organ, it objectivizes it." In the interaction of making a box, the formative indices enact some of Serres' scattering, not in an objectivization of function but in a transduction of material marking. Ahmed's writing about the shaping of the body by its occupation provides the other side of the equation: just as I left my mark on the box's wooden shape, it leaves its mark on the edge of a blade or in resistance to my pressure taken up by my own bodily structure in the form of muscle strain, splinters, and cuts. Michel Serres, *Variations on the Body*, translated by Randolph Burks (Minneapolis: Univocal, 2012), 120.
[^saito-responsibility]: One of Saito's justifications for supporting an aesthetics of the everyday is based in the feeling of responsibility toward objects that aesthetic attention can effect. The conventionally beautiful receives more care than the unremarkable or the ugly as a result, but distributing aesthetic attention more equitably would also bring about a similarly equitable distribution of care. I want to suggest here a coupling of aesthetic-attention-induced responsibility with the responsibility that comes from authorship and from sunk cost. Yuriko Saito, "Significance of Everyday Aesthetics" in *Everyday Aesthetics* (New York: Oxford University Press, 2007), passim. [https://doi.org/10.1093/acprof:oso/9780199278350.001.0001](https://doi.org/10.1093/acprof:oso/9780199278350.001.0001).

# It continues

Here I've tried to tease out some of my trajectories for thinking about Haptic Box and situate its development in my personal history. There are certainly other threads which I haven't touched on here, which may become more apparent in traversal of some of my other [works](/works.html) and [writing](/writing.html) around and about them.

